@@ -106,15 +106,24 @@ class PrimitiveTypes(object):
         return val
 
     def encode(self, value):
-        if type(value) is str:
+        t = type(value)
+        # if bytes do nothing
+        if t is bytes:
+            return value
+
+        # if string prepare and encode
+        if t is str:
             try:
                 value = self.__prepare(value)
             except ValueError:
                 print("Failed to encode: %s" % value)
                 value = 0
 
-        if type(value) is not list:
+        # if not list convert to list
+        if t is not list:
             value = [value]
+
+        # encode
         values = self.__encoder(len(value), value)
 
         return values
